// Cobb slide design
// Dummy microscope slide to hold a coverslip
// Cheers Giorgio Pattarini 30 Gennaio 2023

//parameters:

slide_length= 76;
slide_width=25;
//Tot thickness of the slide
tot_thick=1.9;


// Round or rectangular coverslip
Coverslip="Round"; //[Round, Rectangular]
// For round coverslip
slide_diam_raw=10.5;
// For rectangular coverslip
coverslip_length_r= 20.1;
coverslip_width_r=20.1;

// Coverslip thickness, or depth of the coverslip inset
coverslip_thick= 0.25;
//Type of coverslip mounting method
mount="Flush"; //[Flush, Sliding]


/*[Fine tweaks]*/
// place the coverslip on the side
off_center=0.1;
//Width of coverslip support
support=1.2;
// taper angle of bore, degrees
bore_taper=45;
//height straight bore section
bore_straight=0.3;
// radius of coverslip chamfers
slide_chamfer=1.5;
// tolerance margin coverslip groove 
tol_coverslip=0.3;
//Depth of the bodies to carve the grooves
carve_depth=10;
// the height of the rails for sliding in
rail_height=0.8;
// the height of the pins that keeps the coverslip i
pin_height=0.4;

// divisions for 3D rendering
 $fn=50;

//add tolerances to the coverslip groove
slide_diam=slide_diam_raw + 2*tol_coverslip;
coverslip_length=coverslip_length_r + 2*tol_coverslip;
coverslip_width=coverslip_width_r + 2*tol_coverslip;

/*
 birra =  [ [0,0],
 [slide_length/2 -slide_chamfer,slide_width ], [slide_length/2, slide_width- slide_chamfer],[0,0]  ];
 // c'e' sempre una funzione birra
*/


if(mount=="Flush")
{
difference(){
    //the slide main body
linear_extrude(tot_thick)
hull(){
for(i=[-1,1]){
    for(j=[-1,1]){
        translate([i*(slide_length/2-slide_chamfer), j*(slide_width/2-slide_chamfer) ])
        circle(slide_chamfer);
    }
}
};

if(Coverslip=="Round")
{ 
translate([off_center, 0, tot_thick-coverslip_thick])
union(){
    // coverslip groove
    cylinder(carve_depth, slide_diam/2, slide_diam/2); 
    //straight bore under coverslip
    translate([0,0,-carve_depth+0.1])cylinder(carve_depth, slide_diam/2-support, slide_diam/2-support);
    //tapered bore under coverslip
    translate([0,0,-carve_depth-bore_straight])cylinder(carve_depth, (slide_diam/2-support) + carve_depth*tan(
    bore_taper), slide_diam/2-support);
    }
};

if(Coverslip=="Rectangular")
    translate([0, off_center,0])
 union(){   
 
    //The coverslip groove
    translate([0,0,tot_thick-coverslip_thick])
  linear_extrude(carve_depth)    
polygon(points=[
    [(coverslip_length/2),(coverslip_width/2)],
    [(coverslip_length/2),-(coverslip_width/2)],
    [-(coverslip_length/2),-(coverslip_width/2)],
    [-(coverslip_length/2),(coverslip_width/2)]
    ]);
    
    //the small straight section
    translate([0,0,0])
    linear_extrude(carve_depth)   
polygon(points=[
    [(coverslip_length/2-support),(coverslip_width/2-support)],
    [(coverslip_length/2-support),-(coverslip_width/2-support)],
    [-(coverslip_length/2-support),-(coverslip_width/2-support)],
    [-(coverslip_length/2-support),(coverslip_width/2-support)]
    ]);
    
    // the tapered bore
       translate([0,0,tot_thick-coverslip_thick-bore_straight]) 
      mirror([0,0,1]) 
      linear_extrude(carve_depth, 
      scale = (
      (2*carve_depth*tan(bore_taper)+ max(coverslip_width, coverslip_length) ) /(  max(coverslip_width, coverslip_length))))
polygon(points=[
    [(coverslip_length/2-support),(coverslip_width/2-support)],
    [(coverslip_length/2-support),-(coverslip_width/2-support)],
    [-(coverslip_length/2-support),-(coverslip_width/2-support)],
    [-(coverslip_length/2-support),(coverslip_width/2-support)]
    ]);    
};
};
};



//modules etc for sliding mount

rail_width=
(Coverslip=="Round")? 
slide_diam/2
:
coverslip_width/2;

clips_length=
(Coverslip=="Round")? 
slide_diam/2
:
coverslip_length/2;

//The rail that keeps the slide down
module rail(){
rotate(a=90, v=[0,-1,0])
  linear_extrude(2*clips_length+24, center=true)    
polygon(points=[   
    [tot_thick -0.1, slide_width/2],
    [tot_thick + coverslip_thick+rail_height, slide_width/2],
    [tot_thick + coverslip_thick+rail_height-0.2, rail_width-rail_height-0.2],
    [tot_thick + coverslip_thick+rail_height-0.2, rail_width-rail_height-0.2],
    [tot_thick + coverslip_thick, rail_width],
    [tot_thick -0.1, rail_width]
    ]);}

//The press clips that stop the coverslip
module clip(){
rotate(a=90, v=[1,0,0])
  linear_extrude(4, center=true)    
polygon(points=[   
    [clips_length+ support, tot_thick -0.1],
    [clips_length+ support, tot_thick + pin_height],
    [clips_length+support +1, tot_thick + pin_height],
    [clips_length+support +4, tot_thick -0.1],  
    ]);}


if(mount=="Sliding"){

difference(){
union(){
//the slide main body
linear_extrude(tot_thick)
hull(){
for(i=[-1,1]){
    for(j=[-1,1]){
        translate([i*(slide_length/2-slide_chamfer), j*(slide_width/2-slide_chamfer) ])
        circle(slide_chamfer);
    }}};

//the two side rails
rail();
rotate (a=180, v=[0,0,1]) rail();
//the two clips
clip();
rotate (a=180, v=[0,0,1]) clip();


};

// the holes to help insert the coverslip
translate([clips_length+6
, 0,0])
cylinder (carve_depth, 2,2
,center=true);
translate([-(clips_length+6
), 0,0])
cylinder (carve_depth, 2,2
,center=true);


//the main bores
if(Coverslip=="Round")
{ 
translate([off_center, 0,0])
union(){
    //straight bore under coverslip
    translate([0,0,-carve_depth+tot_thick+0.1])cylinder(carve_depth, slide_diam/2-support, slide_diam/2-support);
    //tapered bore under coverslip
    translate([0,0,-carve_depth + tot_thick-bore_straight])cylinder(carve_depth, (slide_diam/2-support) + carve_depth*tan(bore_taper), slide_diam/2-support);
    }
};


if(Coverslip=="Rectangular"){
    translate([0, off_center,0])
 union(){   
   
    //the small straight section
    translate([0,0,-carve_depth+tot_thick+0.1])
    linear_extrude(carve_depth)   
polygon(points=[
    [(coverslip_length/2-support),(coverslip_width/2-support)],
    [(coverslip_length/2-support),-(coverslip_width/2-support)],
    [-(coverslip_length/2-support),-(coverslip_width/2-support)],
    [-(coverslip_length/2-support),(coverslip_width/2-support)]
    ]);
    
    // the tapered bore
       translate([0,0,tot_thick-bore_straight]) 
      mirror([0,0,1]) 
      linear_extrude(carve_depth, 
      scale = (
      (2*carve_depth*tan(bore_taper)+ max(coverslip_width, coverslip_length) ) /(  max(coverslip_width, coverslip_length))))
polygon(points=[
    [(coverslip_length/2-support),(coverslip_width/2-support)],
    [(coverslip_length/2-support),-(coverslip_width/2-support)],
    [-(coverslip_length/2-support),-(coverslip_width/2-support)],
    [-(coverslip_length/2-support),(coverslip_width/2-support)]
    ]);    
};
};
};





};

   

    








